Package: tidyindex
Type: Package
Title: A Tidy Data Pipeline to Construct, Compare, and Analyse Indexes
Version: 0.1.0
Authors@R: c(
    person("H. Sherry","Zhang", email = "huize.zhang@monash.edu", role = c("aut","cre", "cph"), comment = c(ORCID = "0000-0002-7122-1463")),
    person("Dianne", "Cook", email = "dicook@monash.edu", role = "aut", comment = c(ORCID = "0000-0002-3813-7155")),
    person("Ursula", "Laa", email = "ursula.laa@boku.ac.at", role = "aut", comment = c(ORCID = "0000-0002-0249-6439")),
    person("Nicolas", "Langrené", email = "nicolas.langrene@csiro.au", role = "aut", comment = c(ORCID = "0000-0001-7601-4618")),
    person("Patricia", "Menéndez", email = "patricia.menendez@monash.edu", role = "aut", comment = c(ORCID = "0000-0003-0701-6315"))
    )
Description: Construct and analyse indexes in a pipeline tidy workflow.
    'tidyindex' contains modules for transforming variables, aggregating 
    variables across time, reducing data dimension through weighting, and 
    fitting distributions. A manuscript describing the methodology can be 
    found at <https://github.com/huizezhang-sherry/paper-tidyindex>.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
URL: https://github.com/huizezhang-sherry/tidyindex
BugReports: https://github.com/huizezhang-sherry/tidyindex/issues
Imports: cli, dplyr, generics, ggplot2, glue, purrr, rlang (>= 1.1.0),
        tidyr, tidyselect, tsibble, vctrs
RoxygenNote: 7.2.3
Suggests: covr, knitr, lmomco, lubridate, rmarkdown, slider, SPEI,
        testthat (>= 3.0.0)
Config/testthat/edition: 3
Depends: R (>= 2.10)
VignetteBuilder: knitr
Author: H. Sherry Zhang [aut, cre, cph]
    (<https://orcid.org/0000-0002-7122-1463>),
  Dianne Cook [aut] (<https://orcid.org/0000-0002-3813-7155>),
  Ursula Laa [aut] (<https://orcid.org/0000-0002-0249-6439>),
  Nicolas Langrené [aut] (<https://orcid.org/0000-0001-7601-4618>),
  Patricia Menéndez [aut] (<https://orcid.org/0000-0003-0701-6315>)
Maintainer: H. Sherry Zhang <huize.zhang@monash.edu>
Built: R 4.4.0; ; 2024-05-03 05:52:51 UTC; unix
