# Generated by roxygen2: do not edit by hand

S3method(augment,idx_res)
S3method(print,idx_tbl)
export(add_paras)
export(aggregate_geometrical)
export(aggregate_linear)
export(aggregate_manual)
export(compute_indexes)
export(dimension_reduction)
export(dist_gamma)
export(dist_gev)
export(dist_glo)
export(dist_pe3)
export(distribution_fit)
export(idx_edi)
export(idx_rdi)
export(idx_spei)
export(idx_spi)
export(init)
export(norm_quantile)
export(normalise)
export(rescale_center)
export(rescale_minmax)
export(rescale_zscore)
export(rescaling)
export(swap_exprs)
export(swap_values)
export(temporal_aggregate)
export(temporal_rolling_window)
export(theme_benchmark)
export(trans_cubic_root)
export(trans_log10)
export(trans_quadratic)
export(trans_square_root)
export(variable_trans)
importFrom(cli,cli_abort)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,enquo)
importFrom(dplyr,enquos)
importFrom(dplyr,ensym)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,nest_by)
importFrom(dplyr,pull)
importFrom(dplyr,quo)
importFrom(dplyr,quo_name)
importFrom(dplyr,rowwise)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(generics,augment)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(purrr,pmap)
importFrom(rlang,":=")
importFrom(rlang,as_function)
importFrom(rlang,as_label)
importFrom(rlang,enexpr)
importFrom(rlang,expr)
importFrom(rlang,sym)
importFrom(stats,qnorm)
importFrom(stats,sd)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,unnest)
importFrom(tidyselect,eval_select)
importFrom(tsibble,yearmonth)
importFrom(vctrs,s3_register)
